__version__ = "0.1.0"

# Basic functions
from fundamentals.basic_functions import is_empty_string, now_string, now_string_short, now_date, now_year

# Exceptions
from fundamentals.exceptions import BaseScriptError, StringUtilError, ExtendedEnumError

# Extended enums
from fundamentals.extended_enum import ExtendedEnum, ExtendedFlag, EnumListType

# Overrides
from fundamentals.overrides import OverrideChecker, overrides

# Threading
from fundamentals.thread_with_return import ReturningThread

# Bash utilities
from fundamentals.bash import (
    get_effective_user, get_logged_in_user, assert_is_root, number_of_cores, 
    hostname, get_ip, get_external_ip, is_tool_installed, assert_tools_installed
)

# String utilities
from fundamentals.string_utils import (
    Encodings, IdentifierStringCase, FALSE_STRINGS, TRUE_STRINGS,
    input_value, squeeze_chars, remove_control_chars, matches_any,
    replace_all, normalise_sentence, get_random_string, contains_at_least_n_of,
    is_cpp_id, make_cpp_id, identify_case, split_text_into_chunks,
    is_utf8_ascii, is_roman_numeral, roman_to_integer
)



#!/bin/env python3
# Repository:   https://github.com/PyFundamentals
# File Name:    test/test_bash.py
# Description:  test bash utilities
#
# Copyright (C) 2025 Dieter J Kybelksties <github@kybelksties.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
# @date: 2025-10-27
# @author: Dieter J Kybelksties

import unittest
import socket

from fundamentals.bash import get_effective_user, get_logged_in_user, number_of_cores, hostname, get_ip, is_tool_installed


class BashTests(unittest.TestCase):

    def test_get_effective_user(self):
        user = get_effective_user()
        self.assertIsInstance(user, str)
        self.assertTrue(len(user) > 0)

    def test_get_logged_in_user(self):
        user = get_logged_in_user()
        self.assertIsInstance(user, str)
        self.assertTrue(len(user) > 0)

    def test_number_of_cores(self):
        cores = number_of_cores()
        self.assertIsInstance(cores, int)
        self.assertGreater(cores, 0)

    def test_hostname(self):
        hn = hostname()
        self.assertIsInstance(hn, str)
        self.assertTrue(len(hn) > 0)

    def test_get_ip(self):
        ip = get_ip()
        self.assertIsInstance(ip, str)
        # Should be a valid IP
        try:
            socket.inet_aton(ip)
        except socket.error:
            self.fail("get_ip returned invalid IP")

    def test_is_tool_installed(self):
        # Test a common tool
        self.assertTrue(is_tool_installed("python") or is_tool_installed("python3"))
        self.assertFalse(is_tool_installed("nonexistent_tool_12345"))


if __name__ == '__main__':
    unittest.main()
